#[non_exhaustive]pub enum DecryptionError {
ChaCha(Error),
Decompression(DecompressionError),
Ecc(DecodeError),
Hash(HashError),
KeyMismatch,
}Expand description
Errors returned by decrypt.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ChaCha(Error)
Returned if ChaCha20-Poly1305 rejects the ciphertext or key.
Decompression(DecompressionError)
Returned if decompression fails or the output would exceed the key’s length bound.
Ecc(DecodeError)
Returned if ECC decoding fails.
Hash(HashError)
Returned if hashing the decrypted data fails.
KeyMismatch
Returned if the decrypted data does not hash to the decryption key.